==> bob.bio.spear-3.1.0-py_0.tar.bz2: link.py <==
DATA = {
  "Examples": [], 
  "dist": "bob.bio.spear-3.1.0-py_0", 
  "python-scripts": [], 
  "site-packages": [
    "bob.bio.spear-3.1.0-py3.6.egg-info/PKG-INFO", 
    "bob.bio.spear-3.1.0-py3.6.egg-info/SOURCES.txt", 
    "bob.bio.spear-3.1.0-py3.6.egg-info/dependency_links.txt", 
    "bob.bio.spear-3.1.0-py3.6.egg-info/entry_points.txt", 
    "bob.bio.spear-3.1.0-py3.6.egg-info/not-zip-safe", 
    "bob.bio.spear-3.1.0-py3.6.egg-info/requires.txt", 
    "bob.bio.spear-3.1.0-py3.6.egg-info/top_level.txt", 
    "bob/bio/spear/__init__.py", 
    "bob/bio/spear/algorithm/__init__.py", 
    "bob/bio/spear/config/__init__.py", 
    "bob/bio/spear/config/algorithm/__init__.py", 
    "bob/bio/spear/config/algorithm/gmm_regular_banca.py", 
    "bob/bio/spear/config/algorithm/gmm_timit.py", 
    "bob/bio/spear/config/algorithm/gmm_tomi.py", 
    "bob/bio/spear/config/algorithm/gmm_tomi_scfc.py", 
    "bob/bio/spear/config/algorithm/gmm_voxforge.py", 
    "bob/bio/spear/config/algorithm/isv_avspoof.py", 
    "bob/bio/spear/config/algorithm/isv_mobio.py", 
    "bob/bio/spear/config/algorithm/isv_voxforge.py", 
    "bob/bio/spear/config/algorithm/ivec_avspoof.py", 
    "bob/bio/spear/config/algorithm/ivec_cosine_voxforge.py", 
    "bob/bio/spear/config/algorithm/ivec_plda_mobio.py", 
    "bob/bio/spear/config/algorithm/ivec_plda_voxforge.py", 
    "bob/bio/spear/config/algorithm/jfa_voxforge.py", 
    "bob/bio/spear/config/database/__init__.py", 
    "bob/bio/spear/config/database/asvspoof.py", 
    "bob/bio/spear/config/database/asvspoof2017.py", 
    "bob/bio/spear/config/database/avspoof.py", 
    "bob/bio/spear/config/database/mobio_audio_female.py", 
    "bob/bio/spear/config/database/mobio_audio_male.py", 
    "bob/bio/spear/config/database/timit.py", 
    "bob/bio/spear/config/database/timit/2/dev/for_models.lst", 
    "bob/bio/spear/config/database/timit/2/dev/for_scores.lst", 
    "bob/bio/spear/config/database/timit/2/eval/for_models.lst", 
    "bob/bio/spear/config/database/timit/2/eval/for_scores.lst", 
    "bob/bio/spear/config/database/timit/2/norm/train_world.lst", 
    "bob/bio/spear/config/database/voicepa.py", 
    "bob/bio/spear/config/extractor/__init__.py", 
    "bob/bio/spear/config/extractor/cqcc20.py", 
    "bob/bio/spear/config/extractor/htk.py", 
    "bob/bio/spear/config/extractor/imfcc20.py", 
    "bob/bio/spear/config/extractor/lfcc20.py", 
    "bob/bio/spear/config/extractor/lfcc_60.py", 
    "bob/bio/spear/config/extractor/mfcc20.py", 
    "bob/bio/spear/config/extractor/mfcc_60.py", 
    "bob/bio/spear/config/extractor/rfcc20.py", 
    "bob/bio/spear/config/extractor/scfc20.py", 
    "bob/bio/spear/config/extractor/scmc20.py", 
    "bob/bio/spear/config/extractor/spro.py", 
    "bob/bio/spear/config/extractor/ssfc20.py", 
    "bob/bio/spear/config/grid/__init__.py", 
    "bob/bio/spear/config/grid/demanding.py", 
    "bob/bio/spear/config/grid/modest.py", 
    "bob/bio/spear/config/preprocessor/__init__.py", 
    "bob/bio/spear/config/preprocessor/energy_2gauss.py", 
    "bob/bio/spear/config/preprocessor/energy_thr.py", 
    "bob/bio/spear/config/preprocessor/external.py", 
    "bob/bio/spear/config/preprocessor/mod_4hz.py", 
    "bob/bio/spear/database/__init__.py", 
    "bob/bio/spear/database/asvspoof.py", 
    "bob/bio/spear/database/asvspoof2017.py", 
    "bob/bio/spear/database/avspoof.py", 
    "bob/bio/spear/database/database.py", 
    "bob/bio/spear/database/mobio.py", 
    "bob/bio/spear/database/voicepa.py", 
    "bob/bio/spear/extractor/CQCCFeatures.py", 
    "bob/bio/spear/extractor/Cepstral.py", 
    "bob/bio/spear/extractor/HTKFeatures.py", 
    "bob/bio/spear/extractor/SPROFeatures.py", 
    "bob/bio/spear/extractor/__init__.py", 
    "bob/bio/spear/extractor/cepstral_extended.py", 
    "bob/bio/spear/preprocessor/Base.py", 
    "bob/bio/spear/preprocessor/Energy_2Gauss.py", 
    "bob/bio/spear/preprocessor/Energy_Thr.py", 
    "bob/bio/spear/preprocessor/External.py", 
    "bob/bio/spear/preprocessor/Mod_4Hz.py", 
    "bob/bio/spear/preprocessor/__init__.py", 
    "bob/bio/spear/script/__init__.py", 
    "bob/bio/spear/script/baselines.py", 
    "bob/bio/spear/test/__init__.py", 
    "bob/bio/spear/test/data/lfcc_60.hdf5", 
    "bob/bio/spear/test/data/mfcc_60.hdf5", 
    "bob/bio/spear/test/data/sample.wav", 
    "bob/bio/spear/test/data/vad_energy_2gauss.hdf5", 
    "bob/bio/spear/test/data/vad_energy_thr.hdf5", 
    "bob/bio/spear/test/data/vad_mod_4hz.hdf5", 
    "bob/bio/spear/test/test_databases.py", 
    "bob/bio/spear/test/test_extractors.py", 
    "bob/bio/spear/test/test_preprocessors.py", 
    "bob/bio/spear/utils/__init__.py", 
    "bob/bio/spear/utils/extraction.py"
  ]
}
## END DATA

"""
This is code that is added to noarch Python packages. See
conda_build/noarch_python.py.

"""
import os
from os.path import dirname, exists, isdir, join, normpath
import sys
import shutil


# Silence pyflakes. This variable is added when link.py is written by
# conda_build.noarch_python.
if False:
    DATA = None

THIS_DIR = dirname(__file__)
PREFIX = normpath(sys.prefix)
if sys.platform == 'win32':
    BIN_DIR = join(PREFIX, 'Scripts')
    SITE_PACKAGES = 'Lib/site-packages'
else:
    BIN_DIR = join(PREFIX, 'bin')
    SITE_PACKAGES = 'lib/python%s/site-packages' % sys.version[:3]

# the list of these files is going to be store in info/_files
FILES = []


def _link(src, dst):
    try:
        os.link(src, dst)
        # on Windows os.link raises AttributeError
    except (OSError, AttributeError):
        shutil.copy2(src, dst)


def _unlink(path):
    try:
        os.unlink(path)
    except OSError:
        pass


def pyc_f(f, version_info=sys.version_info):
    if version_info[0] == 2:
        return f + 'c'
    dn, fn = f.rsplit('/', 1)
    return '%s/__pycache__/%s.cpython-%d%d.pyc' % (
              dn, fn[:-3], version_info[0], version_info[1])


def link_files(src_root, dst_root, files):
    for f in files:
        src = join(THIS_DIR, src_root, f)
        dst = join(PREFIX, dst_root, f)
        dst_dir = dirname(dst)
        if not isdir(dst_dir):
            os.makedirs(dst_dir)
        if exists(dst):
            _unlink(dst)
        _link(src, dst)
        f = '%s/%s' % (dst_root, f)
        FILES.append(f)
        if f.endswith('.py'):
            FILES.append(pyc_f(f))


def create_script(fn):
    src = join(THIS_DIR, 'python-scripts', fn)
    dst = join(BIN_DIR, fn)
    if sys.platform == 'win32':
        shutil.copy2(src, dst + '-script.py')
        FILES.append('Scripts/%s-script.py' % fn)
        shutil.copy2(join(THIS_DIR,
                          'cli-%d.exe' % (8 * tuple.__itemsize__)),
                     dst + '.exe')
        FILES.append('Scripts/%s.exe' % fn)
    else:
        with open(src) as fi:
            data = fi.read()
        with open(dst, 'w') as fo:
            fo.write('#!%s\n' % normpath(sys.executable))
            fo.write(data)
        os.chmod(dst, 0o775)
        FILES.append('bin/%s' % fn)


def create_scripts(files):
    if not files:
        return
    if not isdir(BIN_DIR):
        os.mkdir(BIN_DIR)
    for fn in files:
        create_script(fn)


def main():
    create_scripts(DATA['python-scripts'])
    link_files('site-packages', SITE_PACKAGES, DATA['site-packages'])
    link_files('Examples', 'Examples', DATA['Examples'])

    with open(join(PREFIX, 'conda-meta',
                   '%s.files' % DATA['dist']), 'w') as fo:
        for f in FILES:
            fo.write('%s\n' % f)


if __name__ == '__main__':
    main()

==> bob.bio.spear-3.1.1-py_0.tar.bz2: link.py <==
DATA = {
  "Examples": [], 
  "dist": "bob.bio.spear-3.1.1-py_0", 
  "python-scripts": [], 
  "site-packages": [
    "bob/bio/spear/test/test_databases.py", 
    "bob/bio/spear/algorithm/__init__.py", 
    "bob/bio/spear/config/extractor/lfcc20.py", 
    "bob/bio/spear/config/extractor/cqcc20.py", 
    "bob/bio/spear/config/preprocessor/external.py", 
    "bob/bio/spear/config/extractor/scfc20.py", 
    "bob.bio.spear-3.1.1-py3.6.egg-info/PKG-INFO", 
    "bob/bio/spear/extractor/HTKFeatures.py", 
    "bob/bio/spear/config/database/timit/2/eval/for_scores.lst", 
    "bob/bio/spear/test/data/vad_energy_2gauss.hdf5", 
    "bob.bio.spear-3.1.1-py3.6.egg-info/dependency_links.txt", 
    "bob/bio/spear/config/algorithm/isv_mobio.py", 
    "bob/bio/spear/preprocessor/__init__.py", 
    "bob.bio.spear-3.1.1-py3.6.egg-info/entry_points.txt", 
    "bob/bio/spear/config/algorithm/isv_avspoof.py", 
    "bob/bio/spear/config/database/asvspoof2017.py", 
    "bob/bio/spear/script/__init__.py", 
    "bob/bio/spear/config/database/timit/2/norm/train_world.lst", 
    "bob/bio/spear/script/baselines.py", 
    "bob/bio/spear/config/extractor/ssfc20.py", 
    "bob/bio/spear/config/algorithm/gmm_tomi.py", 
    "bob/bio/spear/database/database.py", 
    "bob/bio/spear/test/data/vad_energy_thr.hdf5", 
    "bob/bio/spear/test/data/lfcc_60.hdf5", 
    "bob/bio/spear/config/algorithm/ivec_plda_voxforge.py", 
    "bob/bio/spear/config/extractor/__init__.py", 
    "bob/bio/spear/config/extractor/scmc20.py", 
    "bob/bio/spear/config/__init__.py", 
    "bob/bio/spear/extractor/CQCCFeatures.py", 
    "bob/bio/spear/config/algorithm/ivec_cosine_voxforge.py", 
    "bob/bio/spear/utils/__init__.py", 
    "bob/bio/spear/config/database/mobio_audio_female.py", 
    "bob/bio/spear/config/database/__init__.py", 
    "bob/bio/spear/config/database/timit/2/dev/for_scores.lst", 
    "bob/bio/spear/extractor/Cepstral.py", 
    "bob/bio/spear/test/test_extractors.py", 
    "bob/bio/spear/config/grid/modest.py", 
    "bob/bio/spear/config/algorithm/ivec_avspoof.py", 
    "bob/bio/spear/test/data/mfcc_60.hdf5", 
    "bob/bio/spear/config/extractor/lfcc_60.py", 
    "bob/bio/spear/extractor/SPROFeatures.py", 
    "bob.bio.spear-3.1.1-py3.6.egg-info/not-zip-safe", 
    "bob/bio/spear/database/asvspoof.py", 
    "bob/bio/spear/config/algorithm/gmm_tomi_scfc.py", 
    "bob/bio/spear/config/database/avspoof.py", 
    "bob/bio/spear/database/avspoof.py", 
    "bob/bio/spear/config/extractor/spro.py", 
    "bob/bio/spear/database/voicepa.py", 
    "bob/bio/spear/config/preprocessor/mod_4hz.py", 
    "bob/bio/spear/extractor/__init__.py", 
    "bob.bio.spear-3.1.1-py3.6.egg-info/top_level.txt", 
    "bob/bio/spear/preprocessor/Energy_Thr.py", 
    "bob/bio/spear/config/extractor/mfcc20.py", 
    "bob/bio/spear/config/algorithm/ivec_plda_mobio.py", 
    "bob/bio/spear/extractor/cepstral_extended.py", 
    "bob/bio/spear/config/preprocessor/energy_2gauss.py", 
    "bob.bio.spear-3.1.1-py3.6.egg-info/requires.txt", 
    "bob/bio/spear/config/database/timit.py", 
    "bob/bio/spear/config/grid/demanding.py", 
    "bob/bio/spear/__init__.py", 
    "bob.bio.spear-3.1.1-py3.6.egg-info/SOURCES.txt", 
    "bob/bio/spear/config/extractor/mfcc_60.py", 
    "bob/bio/spear/config/algorithm/gmm_timit.py", 
    "bob/bio/spear/test/data/vad_mod_4hz.hdf5", 
    "bob/bio/spear/config/database/timit/2/eval/for_models.lst", 
    "bob/bio/spear/preprocessor/External.py", 
    "bob/bio/spear/utils/extraction.py", 
    "bob/bio/spear/database/mobio.py", 
    "bob/bio/spear/config/extractor/htk.py", 
    "bob/bio/spear/database/asvspoof2017.py", 
    "bob/bio/spear/config/extractor/rfcc20.py", 
    "bob/bio/spear/config/algorithm/isv_voxforge.py", 
    "bob/bio/spear/config/algorithm/gmm_voxforge.py", 
    "bob/bio/spear/config/extractor/imfcc20.py", 
    "bob/bio/spear/config/grid/__init__.py", 
    "bob/bio/spear/preprocessor/Base.py", 
    "bob/bio/spear/test/data/sample.wav", 
    "bob/bio/spear/test/__init__.py", 
    "bob/bio/spear/config/database/mobio_audio_male.py", 
    "bob/bio/spear/config/algorithm/jfa_voxforge.py", 
    "bob/bio/spear/config/preprocessor/energy_thr.py", 
    "bob/bio/spear/test/test_preprocessors.py", 
    "bob/bio/spear/config/database/timit/2/dev/for_models.lst", 
    "bob/bio/spear/database/__init__.py", 
    "bob/bio/spear/config/algorithm/gmm_regular_banca.py", 
    "bob/bio/spear/config/preprocessor/__init__.py", 
    "bob/bio/spear/preprocessor/Energy_2Gauss.py", 
    "bob/bio/spear/config/database/voicepa.py", 
    "bob/bio/spear/config/algorithm/__init__.py", 
    "bob/bio/spear/preprocessor/Mod_4Hz.py", 
    "bob/bio/spear/config/database/asvspoof.py"
  ]
}
## END DATA

"""
This is code that is added to noarch Python packages. See
conda_build/noarch_python.py.

"""
import os
from os.path import dirname, exists, isdir, join, normpath
import re
import sys
import shutil


# Silence pyflakes. This variable is added when link.py is written by
# conda_build.noarch_python.
if False:
    DATA = None

THIS_DIR = dirname(__file__)
PREFIX = normpath(sys.prefix)
if sys.platform == 'win32':
    BIN_DIR = join(PREFIX, 'Scripts')
    SITE_PACKAGES = 'Lib/site-packages'
else:
    BIN_DIR = join(PREFIX, 'bin')
    SITE_PACKAGES = 'lib/python%s/site-packages' % sys.version[:3]

# the list of these files is going to be store in info/_files
FILES = []

# three capture groups: whole_shebang, executable, options
SHEBANG_REGEX = (br'^(#!'  # pretty much the whole match string
                 br'(?:[ ]*)'  # allow spaces between #! and beginning of the executable path
                 br'(/(?:\\ |[^ \n\r\t])*)'  # the executable is the next text block without an escaped space or non-space whitespace character  # NOQA
                 br'(.*)'  # the rest of the line can contain option flags
                 br')$')  # end whole_shebang group


def _link(src, dst):
    try:
        os.link(src, dst)
        # on Windows os.link raises AttributeError
    except (OSError, AttributeError):
        shutil.copy2(src, dst)


def _unlink(path):
    try:
        os.unlink(path)
    except OSError:
        pass


def pyc_f(f, version_info=sys.version_info):
    if version_info[0] == 2:
        return f + 'c'
    dn, fn = f.rsplit('/', 1)
    return '%s/__pycache__/%s.cpython-%d%d.pyc' % (
              dn, fn[:-3], version_info[0], version_info[1])


def link_files(src_root, dst_root, files):
    for f in files:
        src = join(THIS_DIR, src_root, f)
        dst = join(PREFIX, dst_root, f)
        dst_dir = dirname(dst)
        if not isdir(dst_dir):
            os.makedirs(dst_dir)
        if exists(dst):
            _unlink(dst)
        _link(src, dst)
        f = '%s/%s' % (dst_root, f)
        FILES.append(f)
        if f.endswith('.py'):
            FILES.append(pyc_f(f))


# yanked from conda
def replace_long_shebang(data):
    # this function only changes a shebang line if it exists and is greater than 127 characters
    if hasattr(data, 'encode'):
        data = data.encode()
    shebang_match = re.match(SHEBANG_REGEX, data, re.MULTILINE)
    if shebang_match:
        whole_shebang, executable, options = shebang_match.groups()
        if len(whole_shebang) > 127:
            executable_name = executable.decode('utf-8').split('/')[-1]
            new_shebang = '#!/usr/bin/env %s%s' % (executable_name, options.decode('utf-8'))
            data = data.replace(whole_shebang, new_shebang.encode('utf-8'))
    if hasattr(data, 'decode'):
        data = data.decode()
    return data


def create_script(fn):
    src = join(THIS_DIR, 'python-scripts', fn)
    dst = join(BIN_DIR, fn)
    if sys.platform == 'win32':
        shutil.copy2(src, dst + '-script.py')
        FILES.append('Scripts/%s-script.py' % fn)
        shutil.copy2(join(THIS_DIR,
                          'cli-%d.exe' % (8 * tuple.__itemsize__)),
                     dst + '.exe')
        FILES.append('Scripts/%s.exe' % fn)
    else:
        with open(src) as fi:
            data = fi.read()
        with open(dst, 'w') as fo:
            shebang = replace_long_shebang('#!%s\n' % normpath(sys.executable))
            fo.write(shebang)
            fo.write(data)
        os.chmod(dst, 0o775)
        FILES.append('bin/%s' % fn)


def create_scripts(files):
    if not files:
        return
    if not isdir(BIN_DIR):
        os.mkdir(BIN_DIR)
    for fn in files:
        create_script(fn)


def main():
    create_scripts(DATA['python-scripts'])
    link_files('site-packages', SITE_PACKAGES, DATA['site-packages'])
    link_files('Examples', 'Examples', DATA['Examples'])

    with open(join(PREFIX, 'conda-meta',
                   '%s.files' % DATA['dist']), 'w') as fo:
        for f in FILES:
            fo.write('%s\n' % f)


if __name__ == '__main__':
    main()
